#
# spec file for package libixion
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define libname libixion-0_18-0
Name:           libixion
Version:        0.19.0
Release:        4.2
Summary:        Threaded multi-target formula parser & interpreter
License:        MIT
URL:            https://gitlab.com/ixion/ixion
Source:         http://kohei.us/files/ixion/src/%{name}-%{version}.tar.xz
Patch0:         libixion-boost-system.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-Fix-_WIN32-is-not-defined-when-not-on-Windows.patch
# PATCH-FIX-UPSTREAM
Patch2:         libixion-0.19.0-gcc15-cstdint.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  coreutils
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(mdds-2.1)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(spdlog) >= 0.16.0
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
BuildRequires:  gcc11
BuildRequires:  gcc11-c++
%endif

%description
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

%package -n %{libname}
Summary:        Threaded multi-target formula parser & interpreter

%description -n %{libname}
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

%package devel
Summary:        Threaded multi-target formula parser & interpreter
Requires:       %{libname} = %{version}

%description devel
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

%package tools
Summary:        Spreadsheet file processing library
Requires:       %{libname} = %{version}

%description tools
Tools to use ixion parser and interpreter from cli.

%package -n python3-%{name}
Summary:        Python bindings for libixion
Obsoletes:      %{name}-python
# Renamed in 15.0
Provides:       %{name}-python3 = %{version}

%description -n python3-%{name}
Python 3 bindings for %{name}.

%prep
%autosetup -p1

%build
%global optflags %optflags -fexcess-precision=fast
libtoolize --force --copy
autoreconf -fi
%if 0%{?suse_version} < 1500
export CC=gcc-11
export CXX=g++-11
%endif
%configure \
	--disable-silent-rules \
	--disable-static \
    --disable-vulkan \
	--docdir=%{_docdir}/%{name}
%make_build

%check
%make_build check

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/*

%files -n python3-%{name}
%{python3_sitearch}/ixion.so

%changelog
* Thu Apr 10 2025 Friedrich Haubensak <hsk17@mail.de>
- add libixion-0.19.0-gcc15-cstdint.patch to fix gcc15 compile time
  error
* Tue Jan 14 2025 Christophe Marin <christophe@krop.fr>
- Add upstream change to fix failure with -Werror=undef:
  * 0001-Fix-_WIN32-is-not-defined-when-not-on-Windows.patch
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Jan  8 2024 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.19.0:
  * C++ API
  * added support for renaming sheets after they have been created.
  * formula interpreter
  * added support for inline arrays.
* Thu Jun 29 2023 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.18.1:
  * fixed a 32-bit Linux build issue as discovered on Debian, due to a clash on
  two 32-bit unsigned integer types being used with std::variant.
- Update to 0.18.0:
  * removed the formula_model_access interface from model_context, and switched
    to using model_context directly everywhere.
  * revised formula_tokens_t type to remove use of std::unique_ptr for each
    formula_token instance.  This should improve memory locality when
    iterating through an array of formula token values.  A similar change has
    also been made to lexer_tokens_t and lexer_token types.
  * added 41 built-in functions
  * added support for multi-sheet references in Excel A1 and Excel R1C1
    grammers.
* Thu Mar  2 2023 Martin Liška <mliska@suse.cz>
- Use -fexcess-precision=fast as GCC 13 changes the default
  for C++ compiler and without the change some tests fail on i586.
* Fri Mar  4 2022 Danilo Spinella <danilo.spinella@suse.com>
- Fix build on SLE-12-SP5
- Remove unneeded vulkan dependency
* Thu Jan 27 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * libixion-boost-system.patch
    + fix missing symbols from boost_system library
* Thu Nov 18 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to 0.17.0:
  * set the baseline C++ version to 17.
  * mdds has been internalized so that the public header no longer contains
    references to mdds.  With this change, the users can use different API
    versions of mdds between the ixion build and run-time use.
  * cleaned up public API to make use of std::string_view and std::variant
    where appropriate.
  * implemented built-in LEFT() function in the formula interpreter.
  * it is no longer required to set the size of void* at build time to ensure
    the binaries to be fully functional.
  * fixed a bug where named expressions with names containing invalid
    characters were still allowed in.
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Mon Sep 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.16.1:
  * fixed a build issue on 32-bit linux platforms, caused by slicing of integer
  string ID values.
  * worked around floating point rounding errors which prevented two
  theoretically-equal numeric values from being evaluated as equal in test
  code.
  * added new function to allow printing of single formula tokens.
  * added method for setting cached results on formula cells in
    model_context.
  * changed the model_context design to ensure that all sheets are of the same
    size.
  * added an accessor method to formula_model_access interface (and implicitly
    in model_context) that directly returns a string value from cell.
  * added cell_access class for querying of cell states without knowing its
    type ahead of time.
  * added document class which provides a layer on top of model_context, to
    abstract away the handling of formula calculations.
  * deprecated model_context::erase_cell() in favor of empty_cell().
  * added support for 3D references - references that contain multiple sheets.
  * added support for the exponent (^) and concatenation (&) operators.
  * fixed incorrect handling of range references containing whole columns such
    as A:A.
  * added support for unordered range references - range references whose
    start row or column is greater than their end position counterparts, such
    as A3:A1.
  * fixed a bug that prevented nested formula functions from working properly.
  * implemented Calc A1 style reference resolver.
  * formula results now directly store the string values when the results are
    of string type.  They previously stored string ID values after interning
    the original strings.
  * removed build-time dependency on spdlog.
* Thu Aug 15 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to 0.15.0
  * Update for new liborcus
  * Switched to spdlog for compile-time debug log outputs
  * Various fixes
- Add spdlog build dependency
* Thu Mar  7 2019 Adam Majer <adam.majer@suse.de>
- Add missing dependency on libboost_system-devel
* Thu Nov 15 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.14.1:
  * Update for new orcus
  * Various 23bit build issues
  * Various coverity fixes
* Thu Feb 15 2018 tchvatal@suse.com
- Rename python3 package to match up naming conventions
- Install license file
* Wed Nov 29 2017 tchvatal@suse.com
- Version update to 0.13.0:
  * Step lock update with orcus
  * Various fixes / fuzzer crashes resolved
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Dec  3 2016 tchvatal@suse.com
- Version update to 0.12.1:
  * Update to be in sync with orcus
  * Small fixes around
* Wed May 25 2016 tchvatal@suse.com
- Version update to 0.11.1:
  * Switch to mdds-1.2
  * Few small fixes
* Mon Mar  7 2016 tchvatal@suse.com
- Version update to 0.11.0:
  * Switch to mdds-1.0
  * Various fixes
  * Python3 bindings obsoleted python2 ones
* Mon Apr 13 2015 tchvatal@suse.com
- Version bump to 0.9.1:
  * various triv bugfixes
  * Build with tests and work this time
* Tue Mar 24 2015 tchvatal@suse.com
- Drop copy&pasto from fedora
* Tue Mar 24 2015 tchvatal@suse.com
- Version bump to 0.9.0:
  * Needed for new orcus
  * Python bindings are around now
- Update homepage
- Add python subpackage
- Tests fail with this release, next one will fix it again
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.7.0
  * needed by libreoffice 4.3.x
- Add pkgconfig(mdds) dependency instead of mdds-devel
* Sun Jan 26 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and make the outputs verbose.
* Wed May 15 2013 cfarrell@suse.com
- license update: MIT
  The SPDX shortname for the license described in the COPYING file is MIT
* Sat Apr 20 2013 tchvatal@suse.com
- Add URL path for the download.
- Update the package to be matching the released tarball.
- Do not force autoreconf as it is not really needed with released
  package.
* Wed Mar 27 2013 kyoshida@suse.com
- Updated the package which includes the boost patch and several
  others.
- Removed distro-specific patch.
* Tue Mar 26 2013 tchvatal@suse.com
- Cleanup a bit more for factory inclusion.
* Tue Mar 26 2013 jengelh@inai.de
- Fix wrong order of patch application and broken sed substitution
  in %%prep stage
- Runtime boost dependency is automatic and not needed
* Tue Mar 26 2013 tchvatal@suse.com
- Beautify a bit.
* Tue Mar 26 2013 tchvatal@suse.com
- Fix boost m4 macro to pass configure stage.
* Tue Mar 26 2013 kyoshida@suse.com
- Updated to the 0.5.0 pre-release version.
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Add autotools BuildRequires for factory/12.2
* Thu Oct 27 2011 kyoshida@suse.com
- Initial package.
